/**************************************************************************
  This example is for a 128x64 pixel display using I2C to communicate
  2 pins are required to interface (I2C).

  Adafruit invests time and resources providing this open
  source code, please support Adafruit and open-source
  hardware by purchasing products from Adafruit!

 **************************************************************************/
// Modified 7/31/19  Runs with el cheapo displays.                   -jkl
//
// This demo has SDA to PB7, SCL to PB6, and a pushbutton to ground on PC14.
//
// 9/13/20 Uses push button to select message.         -jkl
//  11/25/20 Began menu system development. Display is the output.               -jkl
// 1/2/21 Demo       -jkl

#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

const int button_1 = 10;      // PC_14

#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels

// Declaration for an SSD1306 display connected to I2C (SDA, SCL pins)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire);


void setup() {
  pinMode (button_1, INPUT_PULLUP);

  if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3C for 128x64
    for (;;); // Don't proceed, loop forever
  }

  // Clear the buffer
  display.clearDisplay();
}
const int menuLen = 8;
char *menuEntry[] = {
  "entry 0",
  "entry 1",
  "entry 2",
  "entry 3",
  "entry 4",
  "entry 5",
  "entry 6",
  "entry 7"
};
// Array of functions for menu actions.
// Each function must declare two integer arguments.
void (*func[])(int, int) = {
  func0,
  func1,
  func0,
  func1,
  func0,
  func1,
  func0,
  func1
};
int mAction = 1;  // tracks the selected item

void loop() {
  int touch;
  int tCount = 0;
  touch = digitalRead(button_1);
  // Press/release cycles thru menu.
  // Press/hold selects menu action.
  if (touch == LOW) {
    while (touch != HIGH) {
      //delay(30);    // this was less stable
      touch = digitalRead(button_1);
      delay(30);    // this seemed solid
      tCount++;
    }
    if (tCount < 50)
    { // press/release action
      mAction++;
      if (mAction >= menuLen)
      {
        mAction = 0;
      }
      display.clearDisplay();
      display.setTextColor(SSD1306_WHITE);
      display.setTextSize(1);
      display.setCursor(0, 0);
      for (int mItem = 0; mItem < menuLen; mItem++)
      {
        if (mItem == mAction)
        {
          display.setTextColor(SSD1306_BLACK, SSD1306_WHITE); // Draw 'inverse' text
          display.println(menuEntry[mItem]);
          display.setTextColor(SSD1306_WHITE);
        } else {
          display.println(menuEntry[mItem]);
        }
      }
      display.display();
    } else {  // press/hold action
      (*func[mAction])(mAction,tCount);
    }
 //   display.display();
  } else {    // place for action if no button press
    ;
  }
}
//
// These functions simply display there arguments.
// They offset the display differently so they can be distinguished.
//
void func0(int act, int cnt)
{
  display.clearDisplay();
  display.setTextColor(SSD1306_WHITE);
  display.setTextSize(4);
  display.setCursor(0, 0);
  display.print (act);
  //display.print (" ");
  display.setCursor(10, 30);
  display.println(cnt);
  display.display();
}

void func1(int act, int cnt)
{
  display.clearDisplay();
  display.setTextColor(SSD1306_WHITE);
  display.setTextSize(4);
  display.setCursor(10, 0);
  display.print (act);
  //display.print (" ");
  display.setCursor(0, 30);
  display.println(cnt);
  display.display();
}

